==> starship-1.14.1.tar.gz: starship-1.14.1/docs/es-ES/presets/README.md <==
# Preajustes

Aqui tienes una colección de preajustes creados por la comunidad de Starship. ¡Si quieres compartir un preajuste, por favor, [envía un PR](https://github.com/starship/starship/edit/master/docs/presets/README.md) actualizando este archivo! 😊

Para obtener detalles sobre cómo utilizar un preajuste, simplemente haga clic en la imagen.

## [Símbolos de Nerd Font](./nerd-font.md)

Este preajuste cambia los símbolos de cada módulo para usar símbolos Nerd Font.

[![Captura de pantalla del preajuste de los Símbolos de Nerd Font](/presets/img/nerd-font-symbols.png "Haga clic para ver el preajuste de Símbolos de Nerd Font")](./nerd-font)

## [Sin fuentes Nerd](./no-nerd-font.md)

This preset changes the symbols for several modules so that no Nerd Font symbols are used anywhere in the prompt.

::: tip

This preset will become the default preset [in a future release of starship](https://github.com/starship/starship/pull/3544).

:::

[Click to view No Nerd Font preset](./no-nerd-font)

## [Segmentos entre Corchetes](./bracketed-segments.md)

Este preajuste cambia el formato de todos los módulos incorporados para mostrar su segmento entre corchetes en lugar de usar la redacción por defecto de Starship ("via", "on", etc.).

[![Captura de pantalla del preajuste de los Segmentos entre Corchetes](/presets/img/bracketed-segments.png "Haga clic para ver el preajuste de Segmentos entre Corchetes")](./bracketed-segments)

## [Símbolos de texto sin formato](./plain-text.md)

Este preajuste cambia los símbolos a texto sin formato. Bueno si usted no tiene acceso a Unicode.

[![Captura de pantalla del ajuste de los Símbolos de Texto Plano](/presets/img/plain-text-symbols.png "Haga clic para ver el preajuste de Símbolos de Texto Sin Formato")](./plain-text)

## [Ocultar Versiones en Tiempo de Ejecución](./no-runtimes.md)

Este preajuste oculta la versión de los tiempos de ejecución del idioma. Si trabajas en contenedores o entornos virtualizados, ¡ésto es para ti!

[![Captura de pantalla del preajuste de Ocultar de versiones de tiempo de ejecución](/presets/img/no-runtime-versions.png "Haga clic para ver el preajuste de Ocultar Versiones en Tiempo de Ejecución")](./no-runtimes)

## [No Empty Icons](./no-empty-icons.md)

This preset does not show icons if the toolset is not found.

[![Screenshot of No Empty Icons preset](/presets/img/no-empty-icons.png "Haga clic para ver el preajuste de Ocultar Versiones en Tiempo de Ejecución")](./no-empty-icons.md)

## [Prompt de Pure](./pure-preset.md)

Esta preajuste emula la apariencia y el comportamiento de [Pure](https://github.com/sindresorhus/pure).

[![Captura de pantalla del ajuste de Pure](/presets/img/pure-preset.png "Haga clic para ver el preajuste del Prompt de Pure")](./pure-preset)

## [Pastel Powerline](./pastel-powerline.md)

Este preajuste está inspirado en [M365Princess](https://github.com/JanDeDobbeleer/oh-my-posh/blob/main/themes/M365Princess.omp.json). También muestra cómo funciona la sustitución de rutas en Starship.

[![Captura de pantalla del preajuste de Pastel Powerline](/presets/img/pastel-powerline.png "Haga clic para ver el preajuste del Prompt de Pure")](./pastel-powerline)

## [Tokyo Night](./tokyo-night.md)

This preset is inspired by [tokyo-night-vscode-theme](https://github.com/enkia/tokyo-night-vscode-theme).

[![Screenshot of Tokyo Night preset](/presets/img/tokyo-night.png "Click to view Tokyo Night preset")](./tokyo-night)

==> starship-1.24.0.tar.gz: starship-1.24.0/docs/es-ES/presets/README.md <==
# Preajustes

Aqui tienes una colección de preajustes creados por la comunidad de Starship. ¡Si quieres compartir un preajuste, por favor, [envía un PR](https://github.com/starship/starship/edit/master/docs/presets/README.md) actualizando este archivo! 😊

Para obtener detalles sobre cómo utilizar un preajuste, simplemente haga clic en la imagen.

## [Símbolos de Nerd Font](./nerd-font.md)

Este preajuste cambia los símbolos de cada módulo para usar símbolos Nerd Font.

[![Captura de pantalla del preajuste de los Símbolos de Nerd Font](/presets/img/nerd-font-symbols.png "Haga clic para ver el preajuste de Símbolos de Nerd Font")](./nerd-font)

## [Sin fuentes Nerd](./no-nerd-font.md)

This preset changes the symbols for several modules so that no Nerd Font symbols are used anywhere in the prompt.

::: tip

This preset will become the default preset [in a future release of starship](https://github.com/starship/starship/pull/3544).

:::

[Click to view No Nerd Font preset](./no-nerd-font)

## [Segmentos entre Corchetes](./bracketed-segments.md)

Este preajuste cambia el formato de todos los módulos incorporados para mostrar su segmento entre corchetes en lugar de usar la redacción por defecto de Starship ("via", "on", etc.).

[![Captura de pantalla del preajuste de los Segmentos entre Corchetes](/presets/img/bracketed-segments.png "Haga clic para ver el preajuste de Segmentos entre Corchetes")](./bracketed-segments)

## [Símbolos de texto sin formato](./plain-text.md)

Este preajuste cambia los símbolos a texto sin formato. Bueno si usted no tiene acceso a Unicode.

[![Captura de pantalla del ajuste de los Símbolos de Texto Plano](/presets/img/plain-text-symbols.png "Haga clic para ver el preajuste de Símbolos de Texto Sin Formato")](./plain-text)

## [Ocultar Versiones en Tiempo de Ejecución](./no-runtimes.md)

Este preajuste oculta la versión de los tiempos de ejecución del idioma. Si trabajas en contenedores o entornos virtualizados, ¡ésto es para ti!

[![Captura de pantalla del preajuste de Ocultar de versiones de tiempo de ejecución](/presets/img/no-runtime-versions.png "Haga clic para ver el preajuste de Ocultar Versiones en Tiempo de Ejecución")](./no-runtimes)

## [No Empty Icons](./no-empty-icons.md)

This preset does not show icons if the toolset is not found.

[![Screenshot of No Empty Icons preset](/presets/img/no-empty-icons.png "Haga clic para ver el preajuste de Ocultar Versiones en Tiempo de Ejecución")](./no-empty-icons.md)

## [Prompt de Pure](./pure-preset.md)

Esta preajuste emula la apariencia y el comportamiento de [Pure](https://github.com/sindresorhus/pure).

[![Captura de pantalla del ajuste de Pure](/presets/img/pure-preset.png "Haga clic para ver el preajuste del Prompt de Pure")](./pure-preset)

## [Pastel Powerline](./pastel-powerline.md)

Este preajuste está inspirado en [M365Princess](https://github.com/JanDeDobbeleer/oh-my-posh/blob/main/themes/M365Princess.omp.json). También muestra cómo funciona la sustitución de rutas en Starship.

[![Captura de pantalla del preajuste de Pastel Powerline](/presets/img/pastel-powerline.png "Haga clic para ver el preajuste del Prompt de Pure")](./pastel-powerline)

## [Tokyo Night](./tokyo-night.md)

Este preset está inspirado en [tokyo-night-vscode-theme](https://github.com/enkia/tokyo-night-vscode-theme).

[![Captura del preset de Tokyo Night](/presets/img/tokyo-night.png "Click to view Tokyo Night preset")](./tokyo-night)

## [Gruvbox Rainbow](./gruvbox-rainbow.md)

Este preajuste está muy inspirado en [Pastel Powerline](./pastel-powerline.md) y [Tokyo Night](./tokyo-night.md).

[![Captura de pantalla de el preajuste Gruvbox Rainbow](/presets/img/gruvbox-rainbow.png "Clic para ver el preajuste Gruvbox Rainbow")](./gruvbox-rainbow)

## [Jetpack](./jetpack.md)

Este es un preajuste pseudominimalista inspirado en las indicaciones [geometría](https://github.com/geometry-zsh/geometry) y [nave espacial](https://github.com/spaceship-prompt/spaceship-prompt).

[![Captura de pantalla del preajuste Jetpack](/presets/img/jetpack.png "Click to view Jetpack preset")](./jetpack)

## [Catppuccin Powerline](./catppuccin-powerline.md)

This preset is a minimally modified version of [Gruvbox Rainbow](./gruvbox-rainbow.md) using the [Catppuccin](https://github.com/catppuccin/catppuccin) theme palette.

[![Screenshot of Catppuccin Powerline preset](/presets/img/catppuccin-powerline.png "Click to view Catppuccin Powerline preset")](./catppuccin-powerline)
